@@ -17,17 +17,17 @@ class TestTeamEndpoint(unittest.TestCase):
 
     def setUp(self):
         """ setUp """
-        self.team = TeamEndpoint(session=requests.Session())
-        self.base = BaseEndpoint(session=requests.Session())
+        self.team = TeamEndpoint(
+            team="Manchester_United", session=requests.Session()
+        )
+        self.base = BaseEndpoint("", session=requests.Session())
 
     def test_get_player_data_return_value(self, mock_get, mock_request_url):
         """ test `get_match_data()` """
         mock_request_url.return_value = mocked_requests_get(
             "test/resources/team.html"
         )
-        data = self.team.get_player_data(
-            team="Manchester_United", season="2019"
-        )
+        data = self.team.get_player_data(season="2019")
         expected_data = pd.read_csv(
             "test/resources/data/team_playersdata.csv", index_col=0
         )
@@ -38,7 +38,7 @@ class TestTeamEndpoint(unittest.TestCase):
         self, mock_get_response, mock_get, mock_request_url
     ):
         """ test `get_player_data()` """
-        self.team.get_player_data(team="Manchester_United", season="2019")
+        self.team.get_player_data(season="2019")
         mock_get_response.assert_called_with(
             url="https://understat.com/team/Manchester_United/2019",
             query="playersData",
@@ -49,9 +49,7 @@ class TestTeamEndpoint(unittest.TestCase):
         mock_request_url.return_value = mocked_requests_get(
             "test/resources/team.html"
         )
-        data = self.team.get_match_data(
-            team="Manchester_United", season="2019"
-        )
+        data = self.team.get_match_data(season="2019")
         data = self.base.unpack_dataframe(data)
         expected_data = pd.read_csv(
             "test/resources/data/team_datesdata.csv", index_col=0
@@ -63,7 +61,7 @@ class TestTeamEndpoint(unittest.TestCase):
         self, mock_get_response, mock_get, mock_request_url
     ):
         """ test `get_match_data()` """
-        self.team.get_match_data(team="Manchester_United", season="2019")
+        self.team.get_match_data(season="2019")
         mock_get_response.assert_called_with(
             url="https://understat.com/team/Manchester_United/2019",
             query="datesData",
@@ -74,9 +72,7 @@ class TestTeamEndpoint(unittest.TestCase):
         mock_request_url.return_value = mocked_requests_get(
             "test/resources/team.html"
         )
-        data = self.team.get_context_data(
-            team="Manchester_United", season="2019"
-        )
+        data = self.team.get_context_data(season="2019")
         data = self.base.unpack_dataframe(data)
         expected_data = pd.read_csv(
             "test/resources/data/team_statisticsdata.csv", index_col=0
@@ -88,7 +84,7 @@ class TestTeamEndpoint(unittest.TestCase):
         self, mock_get_response, mock_get, mock_request_url
     ):
         """ test `get_match_data()` """
-        self.team.get_context_data(team="Manchester_United", season="2019")
+        self.team.get_context_data(season="2019")
         mock_get_response.assert_called_with(
             url="https://understat.com/team/Manchester_United/2019",
             query="statisticsData",
@@ -101,14 +97,21 @@ class TestTeamEndpointErrors(unittest.TestCase):
 
     def setUp(self):
         """ setUp """
-        self.player = TeamEndpoint(session=requests.Session())
+        self.team = TeamEndpoint(team="", session=requests.Session())
 
-    def test_get_data_bad_player(self, mock_get):
+    def test_get_data_bad_team(self, mock_get):
         """ test that `get_data()` raises an InvalidTeam error """
         with self.assertRaises(InvalidTeam):
-            self.player.get_data(
-                team="", season="", query="playersData", status_code=404
-            )
+            self.team.get_data(season="", query="playersData", status_code=404)
+
+    def test_get_data_type_error(self, mock_get):
+        """
+        test that `get_data()` raises a TypeError
+        when `team` is not a string
+        """
+        self.team._primary_attr = None
+        with self.assertRaises(TypeError):
+            _ = self.team.get_data(season="", query="")
 
 
 class TestTeamEndpointDunder(unittest.TestCase):
@@ -116,7 +119,18 @@ class TestTeamEndpointDunder(unittest.TestCase):
 
     def setUp(self):
         """ setUp """
-        self.team = TeamEndpoint(session=requests.Session())
+        self.team = TeamEndpoint(
+            "Manchester_United", session=requests.Session()
+        )
+
+    def test_init(self):
+        """ Test `__init__()` """
+        with self.subTest(test="primary_attr"):
+            self.assertEqual(self.team._primary_attr, "Manchester_United")
+        with self.subTest(test="team"):
+            self.assertEqual(self.team.team, "Manchester_United")
+        with self.subTest(test="session"):
+            self.assertIsInstance(self.team.session, requests.Session)
 
     def test_repr(self):
         """ Test `__repr__()` """
